pub async fn render_standby_gui(
display: &mut DisplayDevice,
render_field_name: bool,
)Expand description
Renders the display in Standby Mode
render_field_name - If true then render the field name of each canbus value
pub async fn render_standby_gui(
display: &mut DisplayDevice,
render_field_name: bool,
)Renders the display in Standby Mode
render_field_name - If true then render the field name of each canbus value